src

package
v0.22.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2026 License: MIT Imports: 35 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateConfig

func CreateConfig() *config.Config

Will be called by traefik

func GetOidcDiscovery

func GetOidcDiscovery(logger *logging.Logger, httpClient *http.Client, providerUrl *url.URL) (*oidc.OidcDiscovery, error)

func New

func New(uctx context.Context, next http.Handler, cfg *config.Config, name string) (http.Handler, error)

Will be called by traefik

Types

type TraefikOidcAuth

type TraefikOidcAuth struct {
	ProviderURL                 *url.URL
	ClientJwtPrivateKey         *rsa.PrivateKey
	CallbackURL                 *url.URL
	Config                      *config.Config
	SessionStorage              session.SessionStorage
	DiscoveryDocument           *oidc.OidcDiscovery
	Jwks                        *oidc.JwksHandler
	Lock                        sync.RWMutex
	BypassAuthenticationRule    *rules.RequestCondition
	RedirectUriWildcardsEnabled bool
	// contains filtered or unexported fields
}

func (*TraefikOidcAuth) EnsureOidcDiscovery

func (toa *TraefikOidcAuth) EnsureOidcDiscovery() error

Make sure we fetch oidc discovery document during first request - avoid race condition Perform lock when changing document - we are in concurrent environment

func (*TraefikOidcAuth) GetAbsoluteCallbackURL

func (toa *TraefikOidcAuth) GetAbsoluteCallbackURL(req *http.Request) *url.URL

func (*TraefikOidcAuth) ServeHTTP

func (toa *TraefikOidcAuth) ServeHTTP(rw http.ResponseWriter, req *http.Request)

Directories

Path Synopsis
Package predicate used to create interpreted mini languages with Go syntax - mostly to define various predicates for configuration, e.g.
Package predicate used to create interpreted mini languages with Go syntax - mostly to define various predicates for configuration, e.g.

Jump to