Documentation
¶
Index ¶
- func ChunkString(input string, chunkSize int) []string
- func Decrypt(ciphertext string, secret string) (string, error)
- func Encrypt(plaintext string, secret string) (string, error)
- func EnsureAbsoluteUrl(req *http.Request, url string) string
- func ExpandEnvironmentVariableBoolean(value string, defaultValue bool) (bool, error)
- func ExpandEnvironmentVariableString(value string) string
- func FillHostSchemeFromRequest(req *http.Request, u *url.URL) *url.URL
- func GetFullHost(req *http.Request) string
- func IsHtmlRequest(req *http.Request) bool
- func ParseBigInt(s string) (*big.Int, error)
- func ParseInt(s string) (int, error)
- func ParseUrl(rawUrl string) (*url.URL, error)
- func UrlIsAbsolute(u *url.URL) bool
- func ValidateRedirectUri(redirectUri string, validUris []string, wildcardsEnabled bool) (string, error)
- type AcceptType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChunkString ¶
func ExpandEnvironmentVariableString ¶
Expands the environment variable if it is enclosed in ${}. If the variable is not present, the original value is returned. Also supports reading the value from a file via ${file:/path/to/file}, eg. to consume a Docker/Kubernetes secret mounted as a file, since environment variables can be read by anyone with access to `docker inspect`.
func GetFullHost ¶
func IsHtmlRequest ¶
func UrlIsAbsolute ¶
Types ¶
type AcceptType ¶
func ParseAcceptHeader ¶
func ParseAcceptHeader(raw string) []AcceptType
func ParseAcceptType ¶
func ParseAcceptType(raw string) AcceptType
Click to show internal directories.
Click to hide internal directories.